@@ -1,12 +1,10 @@
-from __future__ import annotations
-
 from .general import default_print
 from .global_control import disable
 from .global_control import enable
 from .global_control import setup
-from .global_control import setup_for_ipython
+from .global_control import start_ipython
 from .global_control import unload
 from .global_control import update
 from .logger import lk
 
-__version__ = '5.2.1'
+__version__ = '5.2.3'
